Runner

Struct Runner 

pub struct Runner {
    pub name: Option<String>,
    pub as_: Option<String>,
    pub path: Option<String>,
    pub from_dictionary: Option<String>,
    /* private fields */
}
A runner capability

Fields

name: Option<String>

The name of the runner.

as_: Option<String>

A rename of the runner, which can be set when routing to another component. This field is optional.

path: Option<String>

Override the path in which the runner is installed. Instead of /svc/{name}, this value will be used. Path should begin with a leading slash and omit a trailing slash, e.g. /foo/fuchsia.logger.LogSink. This field is optional.

from_dictionary: Option<String>

Optional. If set, the path to the dictionary routed by from which contains the capability. Superseded by [Realm.AddRouteFromDictionary].