Service

Struct Service 

pub struct Service {
    pub name: Option<String>,
    pub as_: Option<String>,
    pub path: Option<String>,
    pub availability: Option<Availability>,
    pub from_dictionary: Option<String>,
    /* private fields */
}
A service capability

Fields

name: Option<String>

The name of the capability. This is usually the name of the FIDL service, e.g. fuchsia.echo.EchoService. If path is not set, the service will be installed in a target component’s namespace at /svc/{name}.

as_: Option<String>

A rename of the capability, which can be set when routing to another component. This field is optional.

path: Option<String>

Override the path in which the service is installed. Instead of /svc/{name}, this value will be used. Path should begin with a leading slash and omit a trailing slash, e.g. /foo/fuchsia.echo.EchoService. This field is optional.

availability: Option<Availability>

Optional. Cannot be set to SameAsTarget if to contains a local component.

from_dictionary: Option<String>

Optional. If set, the path to the dictionary routed by from which contains the capability. Superseded by [Realm.AddRouteFromDictionary].